==========
teslatoken
==========

Simple tool to create tokens for Tesla cars.

Written by Eric Fornstedt.

Description
===========

*teslatoken* is a tool for creating authorization tokens for Tesla Model S/X cars. This is useful to give access for 3rd party applications without giving away your username and password.

The tool is intended to use as a stand alone tool rather than including the module in other python modules.

Installation
============

There are two ways to install the tool:

- Install with: ``§ pip install teslatoken``

or

- Download the repository
- Install the package with: ``§ python setup.py install``

Usage Example
=============

``§ teslatoken -u your.username@tesla.com -p yourpassword``
